@@ -10,6 +10,7 @@ from .yaml_worker import YamlActionsWorker
 from .yaml_worker import YamlDataBaseWorker
 from .sql import SQLite
 from .sql import SQL
+from .yamlbase import main
 
 __all__ = [
     'YamlDataBaseWorker',
@@ -26,5 +27,6 @@ __all__ = [
     'InsertActionImpossibleError',
     'convert_table_data_from_dict_to_table_obj',
     'SQL',
-    'SQLite'
+    'SQLite',
+    'main'
 ]
\ No newline at end of file
