@@ -1,4 +1,4 @@
-"""Main file of YamlBase"""
+"""Main file of yamlbase"""
 
 import argparse
 import yaml
@@ -8,11 +8,11 @@ from yaml_worker import YamlActionsWorker
 
 import sys
 
-if __name__ == '__main__':
 
-    sys.path.append('src/YamlBase')
+def main():
+    sys.path.append('src/yamlbase')
 
-    with open('src/YamlBase/descriptions_cfg.yaml') as f:
+    with open('src/yamlbase/descriptions_cfg.yaml') as f:
         descriptions = yaml.load(f)
 
     parser = argparse.ArgumentParser(description=descriptions['arg_parse_descr'])
@@ -24,4 +24,8 @@ if __name__ == '__main__':
     args = parser.parse_args()
 
     base = YBase(args.cfg_path, args.action)
-    base.do_actions()
\ No newline at end of file
+    base.do_actions()
+
+
+if __name__ == '__main__':
+    raise SystemExit(main())
\ No newline at end of file
