@@ -21,7 +21,7 @@ def main():
     args = parser.parse_args()
 
     base = YBase(args.cfg_path, args.action)
-    # base.do_actions()
+    base.do_actions()
 
 
 if __name__ == '__main__':
