@@ -1,8 +1,8 @@
 """Main module file of yamlbase"""
 
-from dbworkers import SQLiteWorker
-from yaml_worker import YamlDataBaseWorker, YamlActionsWorker
-from exceptions import InsertActionImpossibleError, DataBaseTypeNotFound, ActionNotFound, \
+from YamlBase.dbworkers import SQLiteWorker
+from YamlBase.yaml_worker import YamlDataBaseWorker, YamlActionsWorker
+from YamlBase.exceptions import InsertActionImpossibleError, DataBaseTypeNotFound, ActionNotFound, \
     RemoveActionImpossibleError
 
 
