@@ -1,17 +1,17 @@
 import sys
 from sqlalchemy import create_engine
-sys.path.extend(['../src/yamlbase'])
+import os
 
-from sql import SQLite
-from yaml_worker import YamlDataBaseWorker
+from YamlBase.sql import SQLite
+from YamlBase.yaml_worker import YamlDataBaseWorker
 import pytest
 
 
 class TestSQLite:
 
     def setup(self):
-        self.sqlite_connector = SQLite('', 'test_db.db')
-        self.cfg = YamlDataBaseWorker("test_base.yml")
+        self.sqlite_connector = SQLite('', '../test/test_db.db')
+        self.cfg = YamlDataBaseWorker("../test/test_base.yml")
 
     def test_empty_base(self):
         """Check if base is empty"""
@@ -32,7 +32,7 @@ class TestSQLite:
 
         assert self.sqlite_connector.get_table_data(self.cfg.tables_info[0].schema_name,
                                              self.cfg.tables_info[0].table_name)['name'] == self.cfg.tables_info[0].table_name
-        #
+
         self.sqlite_connector.remove_table(self.cfg.tables_info[0].table_name)
 
     def test_get_table_schema_dict(self):
