@@ -1,9 +1,9 @@
-from utils import convert_table_data_from_dict_to_table_obj
+from YamlBase.utils import convert_table_data_from_dict_to_table_obj
 import yaml
 
 
 def test_convert_table_data_from_dict_to_table_obj():
-    with open('test_base.yml') as f:
+    with open('../test/test_base.yml') as f:
         cfg = yaml.load(f, Loader=yaml.Loader)
 
     test_schema_name = 'main'
